<?php

/**
 * orangi functions and definitions
 *
 * @package Orangi
 */

if (!function_exists('optionsframework_init')) {
    define('OPTIONS_FRAMEWORK_DIRECTORY', esc_url(get_template_directory_uri() . '/inc/'));
    require(get_template_directory() . '/inc/options-framework.php');
}
if (!function_exists('orangi_setup')) :
    function orangi_setup()
    {
        global $content_width;
        if (!isset($content_width)) {
            $content_width = 1014;
        }
        load_theme_textdomain( 'booster', get_template_directory() . '/languages' );
        register_nav_menu('primary', __('Top Menu', "orangi"));
        add_theme_support('automatic-feed-links');
        add_theme_support('post-thumbnails');
        add_theme_support('custom-background');
        $custom_header_support = array(
            'default-text-color' => '000',
            'flex-height' => true,
        );
        set_post_thumbnail_size(150, 150, true);
        add_image_size('small-home', 282, 150);

    }
endif;
add_action('after_setup_theme', 'orangi_setup');

if ( ! function_exists( 'orangi_paginate_page' ) ) :
    function indigos_paginate_page() {
        wp_link_pages( array( 'before' => '<div class="pagination">', 'after' => '</div><div class="clear"></div>', 'link_before' => '<span class="current_pag">','link_after' => '</span>' ) );
    }
endif;

function orangi_load_fonts()
{
    wp_register_style('oswald', 'http://fonts.googleapis.com/css?family=Oswald:400,700');
    wp_enqueue_style('oswald');

    wp_register_style('lato', 'http://fonts.googleapis.com/css?family=Lato');
    wp_enqueue_style('lato');
}

add_action('wp_print_styles', 'orangi_load_fonts');

if (!function_exists('orangi_of_register_js')) :
    function orangi_of_register_js()
    {
        wp_enqueue_script('support', esc_url(get_template_directory_uri() . '/js/support.js'), array('jquery'), '1.0', true);
        wp_enqueue_style('style.css', get_stylesheet_directory_uri() . '/style.css');
        wp_enqueue_style('mediaqueries.css', get_stylesheet_directory_uri() . '/mediaqueries.css');
        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }
    }
endif;
add_action('wp_enqueue_scripts', 'orangi_of_register_js');

function orangi_wp_title($title, $sep)
{
    global $paged, $page;

    if (is_feed())
        return $title;

    // Add the site name.
    $title .= get_bloginfo('name', 'display');

    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && (is_home() || is_front_page()))
        $title = "$title $sep $site_description";

    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2)
        $title = "$title $sep " . sprintf(__('Page %s', 'orangi'), max($paged, $page));

    return $title;
}

add_filter('wp_title', 'orangi_wp_title', 10, 2);

if (!function_exists('orangi_widgets_init')) :
    function orangi_widgets_init()
    {
        register_sidebar(array(
            'name' => __('Blog', 'orangi'),
            'id' => 'blog',
            'description' => __('Blog widget area', 'orangi'),
            'before_widget' => '<section class="widget">',
            'after_widget' => '</section>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3><div class="boxtwosep"></div>',
        ));

        register_sidebar(array(
            'name' => __('Contact', 'orangi'),
            'id' => 'contact',
            'description' => __('Contact widget area', 'orangi'),
            'before_widget' => '<section class="widget">',
            'after_widget' => '</section>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3><div class="boxtwosep"></div>',
        ));

        register_sidebar(array(
            'name' => __('Page', 'orangi'),
            'id' => 'page',
            'description' => __('Page widget area', 'orangi'),
            'before_widget' => '<div class="widget">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));

        register_sidebar(array(
            'name' => __('Footer', 'orangi'),
            'id' => 'footer',
            'description' => __('Footer widget area', 'orangi'),
            'before_widget' => '<div class="box one">',
            'after_widget' => '</div>',
            'before_title' => '<h4>',
            'after_title' => '</h4>',
        ));
    }
endif;
add_action('widgets_init', 'orangi_widgets_init');

if (!function_exists('orangi_credits')) :
    function orangi_credits()
    {
        $text = 'Theme created by <a href="' . esc_url('http://www.wpmodern.com/') . '">WPModern</a>. Powered by <a href="' . esc_url('http://wordpress.org/') . '">WordPress.org</a>';
        echo apply_filters('orangi_credits_text', $text);
    }
endif;
add_action('orangi_display_credits', 'orangi_credits');

if (!function_exists('orangi_content_nav')) :
    function orangi_content_nav($html_id)
    {
        global $wp_query;

        $html_id = esc_attr($html_id);

        if ($wp_query->max_num_pages > 1) : ?>
            <nav id="<?php echo $html_id; ?>" class="navigation" role="navigation">
                <div
                    class="nav-previous"><?php next_posts_link(__('<span class="meta-nav">&larr;</span> Older posts', 'orangi')); ?></div>
                <div
                    class="nav-next"><?php previous_posts_link(__('Newer posts <span class="meta-nav">&rarr;</span>', 'orangi')); ?></div>
            </nav><!-- #<?php echo $html_id; ?> .navigation -->
        <?php endif;
    }
endif;
?>